# -*- coding: utf-8 -*-
# Copyright (C) 2018-2025 Intel Corporation
# SPDX-License-Identifier: Apache-2.0

from openvino.opset16.ops import identity
from openvino.opset16.ops import istft
from openvino.opset16.ops import segment_max
from openvino.opset16.ops import sparse_fill_empty_rows
from openvino.opset16.ops import avg_pool
from openvino.opset16.ops import one_hot
